@@ -22,6 +22,7 @@ pub fn extract_symbol(exchange: &str, market_type: MarketType, msg: &str) -> Opt
         "bybit" => exchanges::bybit::extract_symbol(market_type, msg),
         "coinbase_pro" => exchanges::coinbase_pro::extract_symbol(market_type, msg),
         "deribit" => exchanges::deribit::extract_symbol(market_type, msg),
+        "dydx" => exchanges::dydx::extract_symbol(market_type, msg),
         "ftx" => exchanges::ftx::extract_symbol(market_type, msg),
         "gate" => exchanges::gate::extract_symbol(market_type, msg),
         "huobi" => exchanges::huobi::extract_symbol(market_type, msg),
@@ -47,6 +48,7 @@ pub fn parse_trade(exchange: &str, market_type: MarketType, msg: &str) -> Result
         "bybit" => exchanges::bybit::parse_trade(market_type, msg),
         "coinbase_pro" => exchanges::coinbase_pro::parse_trade(market_type, msg),
         "deribit" => exchanges::deribit::parse_trade(market_type, msg),
+        "dydx" => exchanges::dydx::parse_trade(market_type, msg),
         "ftx" => exchanges::ftx::parse_trade(market_type, msg),
         "gate" => exchanges::gate::parse_trade(market_type, msg),
         "huobi" => exchanges::huobi::parse_trade(market_type, msg),
@@ -85,6 +87,11 @@ pub fn parse_l2(
         "bybit" => exchanges::bybit::parse_l2(market_type, msg),
         "coinbase_pro" => exchanges::coinbase_pro::parse_l2(market_type, msg, timestamp),
         "deribit" => exchanges::deribit::parse_l2(market_type, msg),
+        "dydx" => exchanges::dydx::parse_l2(
+            market_type,
+            msg,
+            timestamp.expect("dYdX orderbook messages don't have timestamp"),
+        ),
         "ftx" => exchanges::ftx::parse_l2(market_type, msg),
         "gate" => exchanges::gate::parse_l2(market_type, msg, timestamp),
         "huobi" => exchanges::huobi::parse_l2(market_type, msg),
